import { Inject, Injectable } from '@angular/core';
import { Location } from '@angular/common';
import { SANDBOXES } from './tokens';
var UrlService = (function () {
    function UrlService(sandboxes, location) {
        this.sandboxes = sandboxes;
        this.location = location;
        this._embed = null;
        this._select = null;
        var urlPath = location.path();
        this._embed = /[?|&]embed=1/.exec(urlPath) !== null;
        this._select = this.parse('scenario', sandboxes, urlPath);
        if (this._select) {
            if (this._select.sandboxKey === null && this._select.scenarioKey === null) {
                this.location.replaceState('');
                return;
            }
        }
    }
    Object.defineProperty(UrlService.prototype, "embed", {
        get: function () {
            return this._embed;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UrlService.prototype, "select", {
        get: function () {
            return this._select;
        },
        enumerable: true,
        configurable: true
    });
    UrlService.prototype.setSelected = function (sandboxKey, scenarioKey) {
        if (sandboxKey === null && scenarioKey === null) {
            this.location.replaceState('');
            return;
        }
        var scenarioDescription = this.sandboxes
            .find(function (sandbox) { return sandbox.key.toLowerCase() === sandboxKey.toLowerCase(); })
            .scenarios.find(function (scenario) { return scenario.key === scenarioKey; }).description;
        this.location.replaceState("?scenario=" + encodeURIComponent(sandboxKey) + "/" + encodeURIComponent(scenarioDescription));
    };
    UrlService.prototype.parse = function (key, sandboxes, urlPath) {
        var match = new RegExp('[?|&]' + key + '=([^&#]*)').exec(urlPath);
        if (match !== null) {
            var value_1 = decodeURIComponent(match[1]);
            var firstSlash_1 = value_1.indexOf('/');
            var filter = value_1.substr(0, firstSlash_1);
            var sandboxKey_1 = filter;
            var sandbox = sandboxes
                .find(function (sandbox) { return sandbox.key.toLowerCase() === sandboxKey_1.toLowerCase(); });
            if (!sandbox) {
                return { filter: filter, sandboxKey: null, scenarioKey: null };
            }
            var scenarioKey = sandbox.scenarios
                .findIndex(function (scenario) { return scenario.description.toLowerCase() === value_1.substr(firstSlash_1 + 1, value_1.length).toLowerCase(); }) + 1;
            if (scenarioKey <= 0) {
                return { filter: filter, sandboxKey: null, scenarioKey: null };
            }
            return { filter: filter, sandboxKey: sandboxKey_1, scenarioKey: scenarioKey };
        }
    };
    return UrlService;
}());
export { UrlService };
UrlService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
UrlService.ctorParameters = function () { return [
    { type: Array, decorators: [{ type: Inject, args: [SANDBOXES,] },] },
    { type: Location, },
]; };
//# sourceMappingURL=url.service.js.map